# Frequently asked questions

[Can the algorithms deal with invalid data, e.g. NaN or inf?](faq/question_02.md)

[What should I do when my 'posterior samples are outside of the prior support' in SNPE?](faq/question_01.md)

[When using multiple workers, I get a pickling error. Can I still use multiprocessing?](faq/question_03.md)

[Can I use the GPU for training the density estimator?](faq/question_04.md)

[How should I save and load objects in `sbi`?](faq/question_05.md)

[Can I stop neural network training and resume it later?](faq/question_06.md)

[How can I use a prior that is not defined in PyTorch?](faq/question_07.md)
